@@ -24,8 +24,8 @@ class ElementHiddenException(BaseCrawlerException):
         super().__init__(message=self.message)
 
 
-class BillingNotAvailableException(BaseCrawlerException):
-    message = 'Billing is not available!'
+class AlreadyPaidException(BaseCrawlerException):
+    message = 'Already Paid error!'
 
     def __init__(self):
         super().__init__(message=self.message)
@@ -38,8 +38,8 @@ class IDNotFoundException(BaseCrawlerException):
         super().__init__(message=self.message)
 
 
-class TechAccountException(BaseCrawlerException):
-    message = 'Tech account error'
+class BadTariffException(BaseCrawlerException):
+    message = 'Base tariff account error'
 
     def __init__(self):
         super().__init__(message=self.message)
